==> plee-the-bear_0.4.1.orig.tar.gz: plee-the-bear-0.4.1/bear-engine/core/src/gui/callback.hpp <==
/*
  Bear Engine

  Copyright (C) 2005-2009 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file callback.hpp
 * \brief Base class for the callbacks of the controls.
 * \author Julien Jorge
 */
#ifndef __GUI_CALLBACK_HPP__
#define __GUI_CALLBACK_HPP__

#include "gui/visual_component.hpp"
#include "gui/class_export.hpp"

namespace bear
{
  namespace gui
  {
    /**
     * \brief Base class for the callbacks of the controls.
     * \author Julien Jorge
     */
    class GUI_EXPORT callback
    {
    public:
      virtual ~callback() {}

      /**
       * \brief Execute the callback.
       * \param control The control that execute this callback.
       */
      virtual void execute( visual_component& control ) = 0;

    }; // class callback
  } // namespace gui
} // namespace bear

#endif // __GUI_CALLBACK_HPP__

==> plee-the-bear_0.5.1.orig.tar.gz: plee-the-bear-0.5.1/bear-engine/core/src/gui/callback.hpp <==
/*
  Bear Engine

  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file callback.hpp
 * \brief Wrapper for base_callback.
 * \author Julien Jorge
 */
#ifndef __GUI_CALLBACK_HPP__
#define __GUI_CALLBACK_HPP__

#include "gui/class_export.hpp"

namespace bear
{
  namespace gui
  {
    class base_callback;

    /**
     * \brief Wrapper for base_callback.
     * \author Julien Jorge
     */
    class GUI_EXPORT callback
    {
    public:
      callback();
      callback( const base_callback& c );
      callback( const callback& that );
      ~callback();

      callback& operator=( const callback& that );

      void execute();

      bool operator==( const callback& that ) const;
      bool operator!=( const callback& that ) const;

    private:
      /** \brief The callback executed by this wrapper. */
      base_callback* m_callback;

    }; // class callback
  } // namespace gui
} // namespace bear

#endif // __GUI_CALLBACK_HPP__
